==> Mapster-1.5.6.1.zip: Mapster/Locale/ptBR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ptBR")
if not L then return end

L["Accuracy"] = "Precisão"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ajuste o tamanho da seta do Jogador no Mapa para melhor visibilidade."
L["Alpha"] = "Transparência"
L["Battlegrounds"] = "Campos de Batalha"
L["BattleMap"] = "Mapa de Batalha"
L["Blobs & Panels"] = "Pontos & Painéis"
L["Burning Crusade Instances"] = "Masmorras do Burning Crusade"
L["Burning Crusade Raids"] = "Raides do Burning Crusade"
L["Cataclysm Instances"] = "Masmorras do Cataclysm"
L["Cataclysm Raids"] = "Raides do Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Muda a escala do mapa se você não quiser que a tela fique toda preenchida enquanto o mapa está aberto."
L["Classic Instances"] = "Masmorras Clássicas"
L["Classic Raids"] = "Raides Clássicas"
L["Coordinates"] = "Coordenadas"
L["Cursor"] = "Cursor"
L["Debug"] = "Debug"
L["Disable Mouse"] = "Desativar Mouse"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Desativar a interatividade do mouse no mapa principal, por exemplo para mudar áreas."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Desativar a interatividade do mouse no mapa principal quando estiver no modo minimizado, por exemplo para mudar áreas."
L["EJ Icon Scale"] = "Tamanho do ícone EJ"
L["Enable BattleMap"] = "Habilitar Mapa de Batalha"
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable FogClear"] = "Habilitar Limpeza de Névoa"
L["Enable Group Icons"] = "Habilitar Ícones do Grupo"
L["Enable Instance Maps"] = "Habilitar Mapas de Masmorras"
L["FogClear"] = "Limpeza de Névoa"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "A Limpeza de Névoa coleta novos dados em suas próprias variáveis salvas, mas os dados podem ficar corrompidos (ou simplesmente velhos) com uma nova atualização. Resete os dados se você ver algo corrompido no mapa."
L["Group Icons"] = "Ícones do Grupo"
L["Hide Border"] = "Ocultar Borda"
L["Hide Completely"] = "Ocultar Completamente"
L["Hide Map Button"] = "Ocultar Botão do Mapa"
-- L["Hide Quest Panels"] = "Hide Quest Panels"
L["Hide Textures"] = "Ocultar Texturas"
L["Hide the borders of the big map."] = "Ocultar bordas do mapa grande."
L["Hide the borders of the minimized map."] = "Ocultar bordas do mapa minimizado."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Ocultar as texturas em volta do Mapa de batalha, apenas deixando você com a pura sobreposição de mapas."
L["Instance Maps"] = "Mapas de Masmorras"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "O Mapster permite você controlar vários aspectos do seu mapa. Você pode mudar o estilo do mapa, controlar o plugins que estendem o mapa com novas funcionalidades, e configurar perfis diferentes para cada um dos seus personagens."
L["(Mini) Disable Mouse"] = "(Mini) Desativar Mouse"
L["(Mini) Hide Border"] = "(Mini) Ocultar Borda"
L["Minimized Alpha"] = "Transparência quando minimizado"
L["Minimized Scale"] = "Escala quando minimizado"
L["Note: You need to reload your UI after reseting the data!"] = "Nota: Você precisa recarregar sua IU após resetar os dados!"
L["Only WorldMap Blobs"] = "Apenas Pontos do Mapa Mundi"
L["Overlay Color"] = "Cor da Sobreposição"
L["Pandaria Instances"] = "Masmorras de Pandaria"
L["Pandaria Raids"] = "Raides de Pandaria"
L["Player"] = "Jogador"
L["PlayerArrow Scale"] = "Escala da Seta do Jogador"
L["POI Scale"] = "Escala dos PDI"
L["Reset FogClear Data"] = "Resetar os dados da Limpeza de Névoa"
L["Scale"] = "Escala"
L["Scale of the big map."] = "Escala do mapa grande."
L["Scale of the Encounter Journal Icons on the Map."] = "Tamanho dos icones do almanaque de encontros no mapa."
L["Scale of the minimized map."] = "Escala do mapa minimizado."
L["Scale of the POI Icons on the Map."] = "Escala dos Ícones dos PDI no mapa."
L["Size on the Battle Map"] = "Tamanho do Mapa de Batalha"
L["Size on the World Map"] = "Tamanho do Mapa Mundi"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "O módulo do Mapa de batalha permite que você mude o estilo do Mini Mapa de Batalha, removendo texturas desnecessárias ou Objetivos JvJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "O módulo de Coordenadas adiciona uma exibição da sua localização atual, e as coordenadas do cursor do seu mouse no Mapa Mundi"
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "O módulo Limpeza de Névoa remove a Névoa da Guerra do seu mapa, exibindo a arte de todas as zonas desconhecidas, opcionalmente com uma sobreposição de cores em áreas desconhecidas."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "O módulo Grupo de Ícones permite redimensionar os ícones da raide e do grupo no mapa."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "O módulo Mapas de Masmorras permite visualizar os Mapas de Masmorras e Campos de Batalha fornecidos pelo jogo mesmo sem você estar na Masmorra."
L["The transparency of the big map."] = "A transparência do mapa grande."
L["The transparency of the minimized map."] = "A transparência do mapa minimizado."
L["Turn on debugging for the FogClear Module."] = "Ativar a depuração para o Módulo Limpeza de Névoa."
L["Wrath Instances"] = "Masmorras do Lich King"
L["Wrath Raids"] = "Raides do Lich King"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Você pode mudar a transparência do mapa para que possa continuar vendo o ambiente enquanto seu mapa está aberto para a navegação."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Você pode controlar a precisão das coordenadas, por exemplo, se você precisar de coordenadas muito exatas você pode definir isso para 2."

==> Mapster-1.6.6.zip: Mapster/Locale/ptBR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ptBR")
if not L then return end

L["Accuracy"] = "Precisão"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ajuste o tamanho da seta do Jogador no Mapa para melhor visibilidade."
L["Alpha"] = "Transparência"
L["BattleMap"] = "Mapa de Batalha"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Muda a escala do mapa se você não quiser que a tela fique toda preenchida enquanto o mapa está aberto."
L["Coordinates"] = "Coordenadas"
L["Cursor"] = "Cursor"
L["Disable Mouse"] = "Desativar Mouse"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Desativar a interatividade do mouse no mapa principal, por exemplo para mudar áreas."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Desativar a interatividade do mouse no mapa principal quando estiver no modo minimizado, por exemplo para mudar áreas."
L["EJ Icon Scale"] = "Tamanho do ícone EJ"
L["Enable BattleMap"] = "Habilitar Mapa de Batalha"
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable FogClear"] = "Habilitar Limpeza de Névoa"
L["Enable Group Icons"] = "Habilitar Ícones do Grupo"
-- L["Faded Alpha"] = "Faded Alpha"
L["FogClear"] = "Limpeza de Névoa"
-- L["Font Size"] = "Font Size"
-- L["Font Size on the minimized map."] = "Font Size on the minimized map."
-- L["Font Size on the normal map."] = "Font Size on the normal map."
L["Group Icons"] = "Ícones do Grupo"
L["Hide Border"] = "Ocultar Borda"
L["Hide Map Button"] = "Ocultar Botão do Mapa"
L["Hide Textures"] = "Ocultar Texturas"
L["Hide the borders of the big map."] = "Ocultar bordas do mapa grande."
L["Hide the borders of the minimized map."] = "Ocultar bordas do mapa minimizado."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Ocultar as texturas em volta do Mapa de batalha, apenas deixando você com a pura sobreposição de mapas."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "O Mapster permite você controlar vários aspectos do seu mapa. Você pode mudar o estilo do mapa, controlar o plugins que estendem o mapa com novas funcionalidades, e configurar perfis diferentes para cada um dos seus personagens."
L["(Mini) Disable Mouse"] = "(Mini) Desativar Mouse"
-- L["(Mini) Font Size"] = "(Mini) Font Size"
L["(Mini) Hide Border"] = "(Mini) Ocultar Borda"
L["Minimized Alpha"] = "Transparência quando minimizado"
L["Minimized Scale"] = "Escala quando minimizado"
L["Overlay Color"] = "Cor da Sobreposição"
L["Player"] = "Jogador"
L["PlayerArrow Scale"] = "Escala da Seta do Jogador"
L["POI Scale"] = "Escala dos PDI"
L["Scale"] = "Escala"
L["Scale of the big map."] = "Escala do mapa grande."
L["Scale of the Encounter Journal Icons on the Map."] = "Tamanho dos icones do almanaque de encontros no mapa."
L["Scale of the minimized map."] = "Escala do mapa minimizado."
L["Scale of the POI Icons on the Map."] = "Escala dos Ícones dos PDI no mapa."
L["Size on the Battle Map"] = "Tamanho do Mapa de Batalha"
L["Size on the World Map"] = "Tamanho do Mapa Mundi"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "O módulo do Mapa de batalha permite que você mude o estilo do Mini Mapa de Batalha, removendo texturas desnecessárias ou Objetivos JvJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "O módulo de Coordenadas adiciona uma exibição da sua localização atual, e as coordenadas do cursor do seu mouse no Mapa Mundi"
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "O módulo Limpeza de Névoa remove a Névoa da Guerra do seu mapa, exibindo a arte de todas as zonas desconhecidas, opcionalmente com uma sobreposição de cores em áreas desconhecidas."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "O módulo Grupo de Ícones permite redimensionar os ícones da raide e do grupo no mapa."
-- L["The map will fade out to the configured Fade Alpha level when you start moving."] = "The map will fade out to the configured Fade Alpha level when you start moving."
L["The transparency of the big map."] = "A transparência do mapa grande."
-- L["The transparency of the map while you are moving and the map is faded."] = "The transparency of the map while you are moving and the map is faded."
L["The transparency of the minimized map."] = "A transparência do mapa minimizado."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Você pode mudar a transparência do mapa para que possa continuar vendo o ambiente enquanto seu mapa está aberto para a navegação."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Você pode controlar a precisão das coordenadas, por exemplo, se você precisar de coordenadas muito exatas você pode definir isso para 2."
